@@ -245,7 +245,13 @@ OLM_EXPORT size_t olm_account_one_time_keys(
     void * one_time_keys, size_t one_time_keys_length
 );
 
-/** Marks the current set of one time keys as being published. */
+/** Marks the current set of one time keys and fallback key as being published
+ * Once marked as published, the one time keys will no longer be returned by
+ * olm_account_one_time_keys(), and the fallback key will no longer be returned
+ * by olm_account_unpublished_fallback_key().
+ *
+ * Returns the number of one-time keys that were marked as published.  Note that
+ * this count does not include the fallback key. */
 OLM_EXPORT size_t olm_account_mark_keys_as_published(
     OlmAccount * account
 );
@@ -291,11 +297,34 @@ OLM_EXPORT size_t olm_account_fallback_key_length(
     OlmAccount const * account
 );
 
+/** Deprecated: use olm_account_unpublished_fallback_key instead */
 OLM_EXPORT size_t olm_account_fallback_key(
     OlmAccount * account,
     void * fallback_key, size_t fallback_key_size
 );
 
+/** The number of bytes needed to hold the unpublished fallback key as returned
+ * by olm_account_unpublished fallback_key. */
+OLM_EXPORT size_t olm_account_unpublished_fallback_key_length(
+    OlmAccount const * account
+);
+
+/** Returns the fallback key (if present, and if unpublished) into the
+ * fallback_key buffer */
+OLM_EXPORT size_t olm_account_unpublished_fallback_key(
+    OlmAccount * account,
+    void * fallback_key, size_t fallback_key_size
+);
+
+/** Forget about the old fallback key.  This should be called once you are
+ * reasonably certain that you will not receive any more messages that use
+ * the old fallback key (e.g. 5 minutes after the new fallback key has been
+ * published).
+ */
+OLM_EXPORT void olm_account_forget_old_fallback_key(
+    OlmAccount * account
+);
+
 
 /** The number of random bytes needed to create an outbound session */
 OLM_EXPORT size_t olm_create_outbound_session_random_length(
@@ -358,7 +387,10 @@ OLM_EXPORT int olm_session_has_received_message(
 
 /**
  * Write a null-terminated string describing the internal state of an olm
- * session to the buffer provided for debugging and logging purposes.
+ * session to the buffer provided for debugging and logging purposes. If the
+ * buffer is not large enough to hold the entire string, it will be truncated
+ * and will end with "...".  A buffer length of 600 will be enough to hold any
+ * output.
  */
 OLM_EXPORT void olm_session_describe(OlmSession * session, char *buf, size_t buflen);
 
